User documentation
==================

The `API reference`_ starts with an overview of all the features and then gets
down to the nitty gritty details of each of them. Most of the reference
provides examples. The `user guide`_ shows you how to depend on the library and
how the various parts of the API can be combined to achieve common tasks. 
For a full overview of features see the `module contents overview`_ of the API
reference and the table of contents of the user guide (in the sidebar) as they
are complementary.

The API reference makes heavy use of a `type language`_; for
example, to describe exactly what arguments can
be passed to a function.  

.. _API reference: api_reference.html
.. _user guide: user_guide.html
.. _module contents overview: api_reference.html#module-contents-overview
.. _type language: type_language.html

.. toctree::
	:maxdepth: 3
	
	user_guide
	api_reference
	type_language
